Modules
Structs
- Body
- Header
Iter - Headers
- Method
- Request
- Expecting Response. Lifetime for using current program data in generation (not result).
- Response
- The out of a Request. Lifetime for using current program data in generation (not result).
- Response
Code
Enums
- Response
Body - Processed body